@@ -16,8 +16,7 @@ from ocrd_utils import (
 from ocrd_modelfactory import page_from_file
 from ocrd_models.ocrd_page import (
     to_xml,
-    WordType, CoordsType, TextEquivType,
-    MetadataItemType, LabelsType, LabelType
+    WordType, CoordsType, TextEquivType
 )
 
 from .config import OCRD_TOOL
@@ -107,21 +106,11 @@ class ANNCorrection(Processor):
             LOG.info("INPUT FILE %i / %s", n, input_file.pageId or input_file.ID)
 
             pcgts = page_from_file(self.workspace.download_file(input_file))
-            page_id = pcgts.pcGtsId or input_file.pageId or input_file.ID # (PageType has no id)
+            page_id = input_file.pageId or input_file.ID # (PageType has no id)
             LOG.info("Correcting text in page '%s' at the %s level", page_id, level)
             
             # annotate processing metadata:
-            metadata = pcgts.get_Metadata() # ensured by from_file()
-            metadata.add_MetadataItem(
-                MetadataItemType(type_="processingStep",
-                                 name=OCRD_TOOL['tools'][TOOL_NAME]['steps'][0],
-                                 value=TOOL_NAME,
-                                 Labels=[LabelsType(
-                                     externalModel="ocrd-tool",
-                                     externalId="parameters",
-                                     Label=[LabelType(type_=name,
-                                                      value=self.parameter[name])
-                                            for name in self.parameter.keys()])]))
+            self.add_metadata(pcgts)
             
             # get textequiv references for all lines:
             # FIXME: conf with TextEquiv alternatives
@@ -199,7 +188,7 @@ def _page_get_line_sequences_at(level, pcgts):
     sequences = list()
     word = None # make accessible after loop
     line = None # make accessible after loop
-    regions = pcgts.get_AllRegions(classes=['Text'], order='reading-order')
+    regions = pcgts.get_Page().get_AllRegions(classes=['Text'], order='reading-order')
     if not regions:
         LOG.warning("Page contains no text regions")
     first_region = True
@@ -596,7 +585,7 @@ def page_update_higher_textequiv_levels(level, pcgts):
     join all first TextEquiv (by the rules governing the respective level)
     into TextEquiv of the next higher level, replacing them.
     '''
-    regions = pcgts.get_AllRegions(classes=['Text'], order='reading-order')
+    regions = pcgts.get_Page().get_AllRegions(classes=['Text'], order='reading-order')
     if level != 'region':
         for region in regions:
             lines = region.get_TextLine()
